<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE xsl:stylesheet [
	<!ENTITY nbsp "&#160;">
	<!ENTITY copy "&#169;">
	<!ENTITY reg "&#174;">
	<!ENTITY trade "&#8482;">
	<!ENTITY mdash "&#8212;">
	<!ENTITY ldquo "&#8220;">
	<!ENTITY rdquo "&#8221;">
	<!ENTITY pound "&#163;">
	<!ENTITY yen "&#165;">
	<!ENTITY euro "&#8364;">
]>
<!-- Addenda de Loreal SLP :: By Daniel Herrera T. :: Version 3.1.0 :: -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:if="https://www.interfactura.com/Schemas/Documentos">
	<xsl:output method="html" encoding="iso-8859-1"/>
	<xsl:template match="/">
		<xsl:element name="if:FacturaInterfactura">
			<xsl:attribute name="TipoDocumento">
				<xsl:text>Factura</xsl:text>
			</xsl:attribute>
			<xsl:element name="if:Emisor">
				<xsl:attribute name="RI">
					<xsl:value-of select="Datos/Emisor/@Referencia"/>
				</xsl:attribute>
			</xsl:element>
			<xsl:element name="if:Receptor">
				<xsl:attribute name="RI">
					<xsl:value-of select="Datos/Receptor/@Referencia"/>
				</xsl:attribute>
			</xsl:element>
			<xsl:element name="if:Encabezado">
				<xsl:attribute name="FolioOrdenCompra">
					<xsl:choose>
						<xsl:when test="Datos/Documento/OrdenesCompra/OrdenCompra/@No !=''">
							<xsl:value-of select="Datos/Documento/OrdenesCompra/OrdenCompra/@No"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="Datos/Documento/@Dato3"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:attribute name="FolioNotaRecepcion">
					<xsl:value-of select="Datos/Documento/RecibosMercancia/ReciboMercancia/@Folio"/>
				</xsl:attribute>
				<xsl:attribute name="NumProveedor">
					<xsl:value-of select="Datos/Emisor/@noProveedor"/>
				</xsl:attribute>
				<xsl:attribute name="Fecha">
					<xsl:value-of select="Datos/CFD/@Fecha"/>
				</xsl:attribute>
				<xsl:attribute name="CondicionPago">
					<xsl:value-of select="Datos/Documento/@PlazoPago"/>
				</xsl:attribute>
				<xsl:attribute name="SubTotal">
					<xsl:value-of select="format-number(Datos/Documento/@SubTotal,&quot;0.0000&quot;)"/>
				</xsl:attribute>
				<xsl:variable name="totIVA" select="Datos/Documento/Impuestos/Impuesto[@Tipo='IVA']/@Importe"/>
				<xsl:attribute name="Iva">
					<xsl:value-of select="format-number($totIVA,&quot;0.0000&quot;)"/>
				</xsl:attribute>
				<xsl:attribute name="Total">
					<xsl:value-of select="format-number(Datos/Documento/@ImpTotal,&quot;0.0000&quot;)"/>
				</xsl:attribute>
				<xsl:variable name="PorIVA" select="Datos/Documento/Impuestos/Impuesto[@Tipo='IVA']/@Porcentaje"/>
				<xsl:attribute name="IVAPCT">
					<xsl:value-of select="format-number($PorIVA,&quot;0&quot;)"/>
				</xsl:attribute>
				<xsl:attribute name="Moneda">
					<xsl:variable name="tpomon" select="Datos/Documento/@TipoMoneda"/>
					<xsl:choose>
						<xsl:when test="$tpomon = 0">
							<xsl:text>MXN</xsl:text>
						</xsl:when>
						<xsl:when test="$tpomon = 1">
							<xsl:text>MXN</xsl:text>
						</xsl:when>
						<xsl:when test="$tpomon = 2">
							<xsl:text>USD</xsl:text>
						</xsl:when>
						<xsl:when test="$tpomon = 3">
							<xsl:text>EUR</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:attribute name="LugarExpedicion">
					<xsl:value-of select="Datos/Documento/@LugarExpedicion"/>
				</xsl:attribute>
				<xsl:attribute name="metodoDePago">
					<xsl:value-of select="Datos/Documento/@MetodoPago"/>
				</xsl:attribute>
				<xsl:attribute name="formaDePago">
					<xsl:value-of select="Datos/Documento/@FormaPago"/>
				</xsl:attribute>
				<xsl:attribute name="RegimenFiscalEmisor">
					<xsl:value-of select="Datos/Emisor/RegimenFiscal/@Regimen"/>
				</xsl:attribute>
				<xsl:attribute name="Serie">
					<xsl:value-of select="Datos/CFD/@Serie"/>
				</xsl:attribute>
				<xsl:attribute name="Folio">
					<xsl:value-of select="Datos/CFD/@Folio"/>
				</xsl:attribute>
				<!--xsl:attribute name="CargoTipo">
					<xsl:value-of select="Datos/Documento/@Dato1"/>
				</xsl:attribute>
				<xsl:attribute name="Observaciones">
					<xsl:value-of select="Datos/Documento/@Observaciones"/>
				</xsl:attribute-->
				<xsl:for-each select="Datos/Documento/Partidas/Partida">
					<xsl:call-template name="Detalle_Partidas"/>
				</xsl:for-each>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="Detalle_Partidas">
		<xsl:element name="if:Cuerpo">
			<xsl:attribute name="Partida">
				<xsl:choose>
					<xsl:when test="./XMLAddenda/Documento/NumeroPartida !=''">
						<xsl:value-of select="format-number(./XMLAddenda/Documento/NumeroPartida,'00000')"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="format-number(position(),'00000')"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="Codigo">
				<xsl:value-of select="@CodigoCliente"/>
			</xsl:attribute>
			<xsl:attribute name="Concepto">
				<xsl:value-of select="@Descripcion"/>
			</xsl:attribute>
			<xsl:attribute name="UnidadMedida">
				<xsl:value-of select="@UnidadMedida"/>
			</xsl:attribute>
			<xsl:attribute name="PUnitario">
				<xsl:value-of select="format-number(@PrecioBruto,&quot;0.0000&quot;)"/>
			</xsl:attribute>
			<xsl:attribute name="Importe">
				<xsl:value-of select="format-number(@ImpNeto,&quot;0.0000&quot;)"/>
			</xsl:attribute>
			<xsl:attribute name="Cantidad">
				<xsl:value-of select="format-number(@Cantidad,&quot;0&quot;)"/>
			</xsl:attribute>
			<!--xsl:variable name="v_ivaimp" select="Impuestos/Impuesto/@Importe"/>
			<xsl:variable name="v_ivapor" select="Impuestos/Impuesto/@Porcentaje"/>
			<xsl:attribute name="Iva">
				<xsl:choose>
					<xsl:when test="$v_ivaimp != ''">
						<xsl:value-of select="format-number($v_ivaimp,&quot;0.00&quot;)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>0.00</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="IVAPCT">
				<xsl:choose>
					<xsl:when test="$v_ivapor != ''">
						<xsl:value-of select="format-number($v_ivapor,&quot;0.00&quot;)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>0.00</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute-->
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>